@@ -94,8 +94,14 @@ class Aviary(bullet_client.BulletClient):
                 )
             )
 
+        # arm everything
         self.armed = [1] * self.num_drones
 
+        # collision array
+        self.collision_array = np.zeros(
+            (self.getNumBodies(), self.getNumBodies()), dtype=bool
+        )
+
     @property
     def num_drones(self):
         return len(self.drones)
@@ -135,7 +141,10 @@ class Aviary(bullet_client.BulletClient):
         """
         Steps the environment
         """
-        self.collisions = set()
+        # reset collisions
+        self.collision_array &= False
+
+        # step the environment enough times for 1 control loop
         for i in range(self.ctrl_update_ratio):
 
             # wait a bit if we're rendering
@@ -172,6 +181,7 @@ class Aviary(bullet_client.BulletClient):
 
             # splice out collisions
             for collision in self.getContactPoints():
-                self.collisions.add([collision.bodyUniqueIdA, collision.bodyUniqueIdB])
+                self.collision_array[collision[1], collision[2]] = True
+                self.collision_array[collision[2], collision[1]] = True
 
         self.steps += 1
