@@ -153,7 +153,7 @@ class SimpleHoverEnv(gymnasium.Env):
 
     def compute_term_trunc_reward(self):
         """compute_term_trunc."""
-        self.reward -= 0.1
+        self.reward += -0.1
 
         # if we've already ended, just exit
         if self.termination or self.truncation:
@@ -164,13 +164,13 @@ class SimpleHoverEnv(gymnasium.Env):
             self.truncation = self.truncation or True
 
         # exceed flight dome
-        if np.linalg.norm(self.state[-3:]) > self.flight_dome_size:
+        if np.linalg.norm(self.env.states[0][-1]) > self.flight_dome_size:
             self.reward += -100.0
             self.info["out_of_bounds"] = True
             self.termination = self.termination or True
 
         # collision
-        if len(self.env.getContactPoints()) > 0:
+        if np.any(self.env.collision_array):
             self.reward += -100.0
             self.info["collision"] = True
             self.termination = self.termination or True
