@@ -289,7 +289,7 @@ class SimpleWaypointEnv(gymnasium.Env):
             self.termination = self.termination or True
 
         # collision
-        if len(self.env.collisions) > 0:
+        if np.any(self.env.collision_array):
             self.reward += -100.0
             self.info["collision"] = True
             self.termination = self.termination or True
