@@ -9,7 +9,10 @@ import PyFlyt
 
 env = gymnasium.make(
     # "PyFlyt/SimpleWaypointEnv-v0", render_mode=None, use_yaw_targets=False, num_targets=5
-    "PyFlyt/SimpleWaypointEnv-v0", render_mode="human", use_yaw_targets=False, num_targets=10,
+    "PyFlyt/SimpleWaypointEnv-v0",
+    render_mode="human",
+    use_yaw_targets=False,
+    num_targets=10,
 )
 
 files = glob.glob("./plots/*")
